@@ -5,15 +5,9 @@ import threading
 from maitai._config import config
 from maitai_gen.chat import ChatCompletionParams, ChatCompletionRequest
 
-version_file_path = os.path.join(os.path.dirname(__file__), "version.py")
-
-with open(version_file_path) as version_file:
-    VERSION = version_file.read().strip()
-
 
 class MaitaiClient:
     MAITAI_HOST = os.environ.get("MAITAI_HOST", 'https://api.trymaitai.ai')
-    VERSION = VERSION
 
     def __init__(self):
         super().__init__()
@@ -43,7 +37,7 @@ class MaitaiClient:
             threading.Thread(target=run).start()
 
     @classmethod
-    def create_inference_request(cls, application_ref_name, session_id, reference_id, action_type, apply_corrections, evaluation_enabled, completion_params: ChatCompletionParams):
+    def create_inference_request(cls, application_ref_name, session_id, reference_id, action_type, apply_corrections, evaluation_enabled, completion_params: ChatCompletionParams, callback):
         infer_request: ChatCompletionRequest = ChatCompletionRequest()
         infer_request.application_ref_name = application_ref_name
         infer_request.reference_id = reference_id
@@ -52,6 +46,6 @@ class MaitaiClient:
         infer_request.apply_corrections = apply_corrections
         infer_request.params = completion_params
         infer_request.evaluation_enabled = evaluation_enabled
-        infer_request.auth_info = config.auth_info
-        infer_request.client_version = cls.VERSION
+        infer_request.auth_keys = config.auth_keys
+        infer_request.return_evaluation = True if callback else False
         return infer_request
